
  - For a list of bug fixes, see
    https://github.com/radical-cybertools/radical.repex/ \
            issues?q=is%3Aissue+is%3Aclosed+sort%3Aupdated-desc
  - For a list of open issues and known problems, see
    https://github.com/radical-cybertools/radical.repex/ \
            issues?q=is%3Aissue+is%3Aopen+


v0.74.0 Release                                                       2022-03-21
--------------------------------------------------------------------------------

  - remove temporary setup files


v0.73.0 Release                                                       2019-11-22
--------------------------------------------------------------------------------

  - add example for external exchange alg select_by_random()
  - add rx profile events
  - fix data staging
  - expose RMQ_HOST/RMQ_PORT
  - extract write_inputs script
  - fix alg return type
  - fix data staging logic, termination logic (allow empty waitlists)
  - Getting ready for full testing
  - linting
  - modify test for wl_size>ex_size
  - support pre_exec
  - Syncing repex with latest RCT changes.
  - terminate when running out of replicas


v0.72.0 Release                                                       2019-09-22
--------------------------------------------------------------------------------

  - recover original history from SM
  - clean out large files
  - repo restrucuting

      
v0.70.0 Release                                                       2019-07-07
--------------------------------------------------------------------------------

  -  move sliding windo alg here
  -  add workload description in json
  -  fix exchange list verification


Version 0.0.1 release                                                 2014-10-31
--------------------------------------------------------------------------------

  -  initial commit for radical project 'repex'


--------------------------------------------------------------------------------

